{ pkgs, ... }:

with import ./network.nix; {
  disabledModules = [ "services/misc/jellyfin.nix" ];
  imports = [ ./modules/jellyfin.nix ];

  services = {
    jellyfin = {
      enable = true;
      package = pkgs.unstable.jellyfin;
    };

    nginx.virtualHosts.${mediadomain} = {
      forceSSL = true;
      enableACME = true;
      locations."/" = {
        proxyPass = "http://localhost:8096";
        extraConfig = ''
          allow 10.0.0.0/24;
          allow 10.3.0.0/24;
          deny all;
        '';
      };
    };
  };

  networking.extraHosts = ''
    ${architect-lan} ${mediadomain}
    ${architect-wg} ${mediadomain}
  '';

  users.groups.media.members = [ "jellyfin" ];
  users.groups.video.members = [ "jellyfin" ];
  users.groups.render.members = [ "jellyfin" ];
}
